@@ -36,7 +36,7 @@ def list_pages_ajax(request, invalid_move=False):
 list_pages_ajax = staff_member_required(list_pages_ajax)
 list_pages_ajax = auto_render(list_pages_ajax)
 
-def modify_content(request, page_id, content_id, language_id):
+def modify_content(request, page_id, content_type, language_id):
     """Modify the content of a page."""
     page = get_object_or_404(Page, pk=page_id)
     perm = PagePermission(request.user).check('change', page=page,
@@ -48,10 +48,10 @@ def modify_content(request, page_id, content_id, language_id):
         page = Page.objects.get(pk=page_id)
         if settings.PAGE_CONTENT_REVISION:
             Content.objects.create_content_if_changed(page, language_id,
-                                                      content_id, content)
+                                                      content_type, content)
         else:
             Content.objects.set_or_create_content(page, language_id,
-                                                  content_id, content)
+                                                  content_type, content)
         page.invalidate()
         # to update last modification date
         page.save()
@@ -66,10 +66,10 @@ def delete_content(request, page_id, language_id):
             lang=language_id, method='POST')
     if not perm:
         raise Http404
-    
+
     for c in Content.objects.filter(page=page, language=language_id):
         c.delete()
-    
+
     destination = request.REQUEST.get('next', request.META.get('HTTP_REFERER',
         '/admin/pages/page/%s/' % page_id))
     return HttpResponseRedirect(destination)
@@ -94,17 +94,19 @@ def traduction(request, page_id, language_id):
 traduction = staff_member_required(traduction)
 traduction = auto_render(traduction)
 
-def get_content(request, page_id, content_id):
+def get_content(request, page_id, content_type):
     """Get the content for a particular page"""
-    content_instance = get_object_or_404(Content, pk=content_id)
-    return HttpResponse(content_instance.body)
+    page = Page.objects.get(pk=page_id)
+    content = Content.objects.get_content(page, request.LANGUAGE_CODE,
+        content_type)
+    return HttpResponse(content)
 get_content = staff_member_required(get_content)
 get_content = auto_render(get_content)
 
 
 def move_page(request, page_id, extra_context=None):
     """Move the page to the requested target, at the given
-    position"""
+    position."""
     page = Page.objects.get(pk=page_id)
 
     target = request.POST.get('target', None)
