@@ -7,7 +7,7 @@ from pages.widgets import ImageInput, VideoWidget
 
 from django import template
 from django.template import TemplateSyntaxError
-from django.core.files.storage import FileSystemStorage
+from django.core.files.storage import default_storage
 from django.forms import Textarea, ImageField, CharField
 from django.forms import TextInput
 from django.conf import settings as global_settings
@@ -120,7 +120,9 @@ class PlaceholderNode(template.Node):
 
     def get_extra_data(self, data):
         """Get eventual extra data for this placeholder from the
-        POST dictionary."""
+        admin form. This method is called when the Page is
+        saved in the admin and passed to the placeholder save
+        method."""
         result = {}
         for key in data.keys():
             if key.startswith(self.name + '-'):
@@ -257,7 +259,6 @@ class ImagePlaceholderNode(PlaceholderNode):
             # the image URL is posted if not changed
             if type(data) is unicode:
                 return
-            storage = FileSystemStorage()
             filename = os.path.join(
                 settings.PAGE_UPLOAD_ROOT,
                 'page_' + str(page.id),
@@ -268,7 +269,7 @@ class ImagePlaceholderNode(PlaceholderNode):
             if m is not None:
                 filename += m.group(0).lower()
 
-            filename = storage.save(filename, data)
+            filename = default_storage.save(filename, data)
             return super(ImagePlaceholderNode, self).save(
                 page,
                 language,
