@@ -78,25 +78,21 @@ class FunctionnalTestCase(TestCase):
         page2 = Content.objects.get_content_slug_by_slug(page_data['slug']).page
         self.assertNotEqual(page1.id, page2.id)
 
+
     def test_details_view(self):
-        """Test the details view."""
+        """Test the details view basics."""
 
         c = self.get_admin_client()
 
-        try:
-            response = c.get(self.get_page_url())
-        except TemplateDoesNotExist, e:
-            if e.args != ('404.html',):
-                raise
+        response = c.get(self.get_page_url())
+        self.assertEqual(response.status_code, 404)
 
         page_data = self.get_new_page_data()
         page_data['status'] = Page.DRAFT
         response = c.post('/admin/pages/page/add/', page_data)
-        try:
-            response = c.get(self.get_page_url())
-        except TemplateDoesNotExist, e:
-            if e.args != ('404.html',):
-                raise
+
+        response = c.get(self.get_page_url())
+        self.assertEqual(response.status_code, 200)
 
         page_data = self.get_new_page_data()
         page_data['status'] = Page.PUBLISHED
@@ -105,11 +101,12 @@ class FunctionnalTestCase(TestCase):
         response = c.post('/admin/pages/page/add/', page_data)
         self.assertRedirects(response, '/admin/pages/page/')
 
-        response = c.get('/pages/test-page-2/')
+        response = c.get(self.get_page_url('test-page-2'))
         self.assertEqual(response.status_code, 200)
 
+
     def test_edit_page(self):
-        """Test that a page can edited via the admin"""
+        """Test that a page can edited via the admin."""
         c = self.get_admin_client()
         c.login(username='batiste', password='b')
         page_data = self.get_new_page_data()
@@ -127,9 +124,10 @@ class FunctionnalTestCase(TestCase):
         body = Content.objects.get_content(page, 'en-us', 'body')
         self.assertEqual(body, 'changed body')
 
+
     def test_site_framework(self):
         """Test the site framework, and test if it's possible to
-        disable it"""
+        disable it."""
 
         from pages import settings as pages_settings
 
@@ -195,6 +193,7 @@ class FunctionnalTestCase(TestCase):
 
         setattr(pages_settings, "SITE_ID", 1)
 
+
     def test_languages(self):
         """Test post a page with different languages
         and test that the admin views works correctly."""
@@ -262,6 +261,7 @@ class FunctionnalTestCase(TestCase):
         self.assertContains(response, 'french title')
         self.assertContains(response, 'lang="fr-ch"')
 
+
     def test_revision(self):
         """Test that a page can edited several times."""
         c = self.get_admin_client()
@@ -289,6 +289,7 @@ class FunctionnalTestCase(TestCase):
         self.assertEqual(Content.objects.get_content(page, 'en-us', 'body'),
             'changed body 2')
 
+
     def test_placeholder(self):
         """
         Test that the placeholder is correctly displayed in
@@ -305,6 +306,7 @@ class FunctionnalTestCase(TestCase):
 
         self.assertContains(response, 'name="right-column"', 1)
 
+
     def test_directory_slug(self):
         """
         Test diretory slugs
@@ -319,7 +321,7 @@ class FunctionnalTestCase(TestCase):
         response = c.post('/admin/pages/page/add/', page_data)
         # the redirect tell that the page has been create correctly
         self.assertRedirects(response, '/admin/pages/page/')
-        response = c.get('/pages/same-slug/')
+        response = c.get(self.get_page_url('same-slug/'))
         self.assertEqual(response.status_code, 200)
 
         page = Page.objects.all()[0]
@@ -373,7 +375,7 @@ class FunctionnalTestCase(TestCase):
         response = c.get(url)
         self.assertEqual(response.status_code, 200)
 
-        url = '/admin/pages/page/%d/get-content/1/' % page.id
+        url = '/admin/pages/page/%d/get-content/slug/' % page.id
         response = c.get(url)
         self.assertEqual(response.status_code, 200)
 
@@ -381,6 +383,7 @@ class FunctionnalTestCase(TestCase):
         response = c.get(url)
         self.assertEqual(response.status_code, 302)
 
+
     def test_page_alias(self):
         """Test page aliasing system"""
 
@@ -424,6 +427,7 @@ class FunctionnalTestCase(TestCase):
         self.assertRedirects(response,
             self.get_page_url('downloads-page'), 301)
 
+
     def test_page_redirect_to(self):
         """Test page redirected to an other page."""
 
@@ -440,6 +444,7 @@ class FunctionnalTestCase(TestCase):
         response = client.get(page1.get_url_path())
         self.assertRedirects(response, page2.get_url_path(), 301)
 
+
     def test_page_valid_targets(self):
         """Test page valid_targets method"""
         c = self.get_admin_client()
@@ -518,6 +523,7 @@ class FunctionnalTestCase(TestCase):
         # Make sure the content response we got was in french
         self.assertTrue('Auteur' in response.content)
 
+
     def test_view_context(self):
         """
         Test that the default view can only return the context
@@ -542,6 +548,7 @@ class FunctionnalTestCase(TestCase):
         request = get_request_mock()
         self.assertEqual(hasattr(request, 'session'), True)
 
+
     def test_tree_admin_interface(self):
         """
         Test that moving/creating page in the tree is working properly
@@ -623,6 +630,7 @@ class FunctionnalTestCase(TestCase):
         response = c.post('/admin/pages/page/%d/' % child_2.id, page_data)
         self.assertEqual(response.status_code, 200)
 
+
     def test_tree(self):
         """
         Test that the navigation tree works properly with mptt.
@@ -687,6 +695,7 @@ class FunctionnalTestCase(TestCase):
         self.assertTrue(response.status_code == 301)
         self.assertTrue(response['Location'] == url)
 
+
     def test_page_freeze_date(self):
         """Test page freezing feature."""
         c = self.get_admin_client()
@@ -735,19 +744,20 @@ class FunctionnalTestCase(TestCase):
         page.delegate_to = 'test'
         page.save()
 
-        response = c.get('/pages/delegate')
+        response = c.get(self.get_page_url('delegate'))
         self.assertEqual(response.status_code, 200)
 
         from pages.testproj.documents.models import Document
         doc = Document(title='doc title 1', text='text', page=page)
         doc.save()
 
-        response = c.get('/pages/delegate/doc-%d' % doc.id)
+        response = c.get(self.get_page_url('delegate/doc-%d' % doc.id))
         self.assertEqual(response.status_code, 200)
 
         self.assertContains(response, "doc title 1")
         reg.registry = []
 
+
     def test_untranslated(self):
         """Test the untranslated feature in the admin."""
         c = self.get_admin_client()
@@ -770,45 +780,48 @@ class FunctionnalTestCase(TestCase):
         response = c.get('/admin/pages/page/%d/?language=fr-ch' % page.id)
         self.assertContains(response, unstranslated_string)
 
+
     def test_root_page(self):
         """Test that the root page doesn't trigger a 404."""
         c = self.get_admin_client()
-        page1 = self.new_page(content={'slug':'this-is-not-a-404'})
+        page1 = self.new_page(content={'slug': 'this-is-not-a-404'})
         self.assertEqual(Page.objects.count(), 1)
         page = Page.objects.on_site()[0]
         self.assertTrue(page.is_first_root())
 
-        response = c.get('/pages/')
+        response = c.get(self.get_page_url())
         self.assertEqual(response.status_code, 200)
 
+
     def test_page_with_trailing_slash(self):
         """
         Test that a page is also available with and without a trailing slash.
         """
         c = self.get_admin_client()
-        page1 = self.new_page(content={'slug':'root'})
-        page2 = self.new_page(content={'slug':'other'})
-        response = c.get('/pages/other')
+        page1 = self.new_page(content={'slug': 'root'})
+        page2 = self.new_page(content={'slug': 'other'})
+        response = c.get(self.get_page_url('other'))
         self.assertEqual(response.status_code, 200)
-        response = c.get('/pages/other/')
+        response = c.get(self.get_page_url('other/'))
         self.assertEqual(response.status_code, 200)
 
+
     def test_page_sitemap(self):
         """
         Test the sitemap class
         """
         c = self.get_admin_client()
-        page1 = self.new_page(content={'slug':'english-slug'})
+        page1 = self.new_page(content={'slug': 'english-slug'})
         page1.save()
         Content(page=page1, language='fr-ch', type='slug',
             body='french-slug').save()
 
         response = c.get('/sitemap.xml')
-        self.assertEqual(response.status_code, 200)
+
         self.assertContains(response, 'english-slug')
         self.assertNotContains(response, 'french-slug')
 
         response = c.get('/sitemap2.xml')
-        self.assertEqual(response.status_code, 200)
+
         self.assertContains(response, 'english-slug')
         self.assertContains(response, 'french-slug')
