@@ -13,6 +13,7 @@ import django
 from django.http import Http404
 from django.contrib.auth.models import User
 from django.conf import settings
+from django.core.urlresolvers import reverse
 from django.template import Template, RequestContext, Context
 from django.template.loader import get_template_from_string
 from django.template import Template, TemplateSyntaxError
@@ -282,7 +283,7 @@ class UnitTestCase(TestCase):
         """
         Test the {% get_content %} template tag
         """
-        page_data = {'title':'test', 'slug':'test'}
+        page_data = {'title': 'test', 'slug': 'test'}
         page = self.new_page(page_data)
 
         context = RequestContext(MockRequest, {'page': page})
@@ -295,6 +296,39 @@ class UnitTestCase(TestCase):
                             '{{ content }}')
         self.assertEqual(template.render(context), page_data['title'])
 
+    def test_get_content_tag_bug(self):
+        """
+        Make sure that {% get_content %} use the "lang" context variable if
+        no language string is provided.
+        """
+        page_data = {'title': 'test', 'slug': 'english'}
+        page = self.new_page(page_data)
+        Content(page=page, language='fr-ch', type='title', body='french').save()
+        Content(page=page, language='fr-ch', type='slug', body='french').save()
+        self.assertEqual(page.slug(language='fr-ch'), 'french')
+        self.assertEqual(page.slug(language='en-us'), 'english')
+
+        # default
+        context = RequestContext(MockRequest, {'page': page})
+        template = Template('{% load pages_tags %}'
+                            '{% get_content page "slug" as content %}'
+                            '{{ content }}')
+        self.assertEqual(template.render(context), 'english')
+
+        # french specified
+        context = RequestContext(MockRequest, {'page': page, 'lang': 'fr'})
+        template = Template('{% load pages_tags %}'
+                            '{% get_content page "slug" as content %}'
+                            '{{ content }}')
+        self.assertEqual(template.render(context), 'french')
+
+        # english specified
+        context = RequestContext(MockRequest, {'page': page, 'lang': 'en-us'})
+        template = Template('{% load pages_tags %}'
+                            '{% get_content page "slug" as content %}'
+                            '{{ content }}')
+        self.assertEqual(template.render(context), 'english')
+
     def test_show_content_tag(self):
         """
         Test the {% show_content %} template tag.
@@ -332,21 +366,25 @@ class UnitTestCase(TestCase):
         """
         Test a {% show_absolute_url %} template tag  bug.
         """
-        page_data = {'title':'english', 'slug':'english'}
+        page_data = {'title': 'english', 'slug': 'english'}
         page = self.new_page(page_data)
         Content(page=page, language='fr-ch', type='title', body='french').save()
         Content(page=page, language='fr-ch', type='slug', body='french').save()
 
-        self.assertEqual(page.get_url_path(language='fr-ch'), u'/pages/french')
-        self.assertEqual(page.get_url_path(language='en-us'), u'/pages/english')
+        self.assertEqual(page.get_url_path(language='fr-ch'),
+            self.get_page_url(u'french'))
+        self.assertEqual(page.get_url_path(language='en-us'),
+            self.get_page_url(u'english'))
 
         context = RequestContext(MockRequest, {'page': page})
         template = Template('{% load pages_tags %}'
                             '{% show_absolute_url page "en-us" %}')
-        self.assertEqual(template.render(context), u'/pages/english')
+        self.assertEqual(template.render(context),
+            self.get_page_url(u'english'))
         template = Template('{% load pages_tags %}'
                             '{% show_absolute_url page "fr-ch" %}')
-        self.assertEqual(template.render(context), u'/pages/french')
+        self.assertEqual(template.render(context),
+            self.get_page_url('french'))
 
     def test_get_page_ids_by_slug(self):
         """
@@ -413,10 +451,13 @@ class UnitTestCase(TestCase):
         req = get_request_mock()
         self.assertRaises(Http404, details, req, '/pages/')
 
-        page1 = self.new_page(content={'slug':'page1'})
-        page2 = self.new_page(content={'slug':'page2'})
+        page1 = self.new_page(content={'slug': 'page1'})
+        page2 = self.new_page(content={'slug': 'page2'})
 
-        self.assertEqual(page1.get_url_path(), '/pages/en-us/page1')
+        self.assertEqual(page1.get_url_path(),
+            reverse('pages-details-by-path', args=[],
+            kwargs={'lang': 'en-us', 'path': 'page1'})
+        )
 
         self.assertEqual(details(req, page1.get_url_path(),
             only_context=True)['current_page'],
@@ -439,21 +480,33 @@ class UnitTestCase(TestCase):
         """
         Check that the root works properly in every case.
         """
-        page1 = self.new_page(content={'slug':'page1'})
+        page1 = self.new_page(content={'slug': 'page1'})
+
         self.set_setting("PAGE_USE_LANGUAGE_PREFIX", False)
         self.set_setting("PAGE_HIDE_ROOT_SLUG", True)
         self.assertEqual(page1.is_first_root(), True)
-        self.assertEqual(page1.get_url_path(), '/pages/')
+        self.assertEqual(page1.get_url_path(),
+            reverse('pages-details-by-path', args=[], kwargs={'path': ''})
+        )
 
         self.set_setting("PAGE_USE_LANGUAGE_PREFIX", True)
-        self.assertEqual(page1.get_url_path(), '/pages/en-us/')
+        self.assertEqual(page1.get_url_path(),
+            reverse('pages-details-by-path', args=[],
+            kwargs={'lang': 'en-us', 'path': ''})
+        )
 
         self.set_setting("PAGE_HIDE_ROOT_SLUG", False)
         page1.invalidate()
-        self.assertEqual(page1.get_url_path(), '/pages/en-us/page1')
+        self.assertEqual(page1.get_url_path(),
+            reverse('pages-details-by-path', args=[],
+            kwargs={'lang': 'en-us', 'path': 'page1'})
+        )
 
         self.set_setting("PAGE_USE_LANGUAGE_PREFIX", False)
-        self.assertEqual(page1.get_url_path(), '/pages/page1')
+        self.assertEqual(page1.get_url_path(),
+            reverse('pages-details-by-path', args=[],
+            kwargs={'path': 'page1'})
+        )
 
     def test_revision_depth(self):
         """
@@ -605,4 +658,11 @@ class UnitTestCase(TestCase):
         p.save()
         self.assertEqual(unicode(p), u"page-%d" % p.id)
 
-
+    def test_context_processor(self):
+        """Test that the page's context processor is properly activated."""
+        from pages.views import details
+        req = get_request_mock()
+        page1 = self.new_page(content={'slug':'page1', 'title':'hello'})
+        page1.save()
+        self.set_setting("PAGES_MEDIA_URL", "test_request_context")
+        self.assertContains(details(req, path='/'), "test_request_context")
